@@ -33,7 +33,7 @@ class PostgresConnectionManager(object):
         if c is None:
             c = self.module.connect(self.dsn)
             c.set_isolation_level(
-                psycopg2.extensions.ISOLATION_LEVEL_SERIALIZABLE)
+                psycopg2.extensions.ISOLATION_LEVEL_READ_COMMITTED)
             self._connection = c
         return c
 
@@ -133,4 +133,4 @@ def safe_close(obj):
         try:
             obj.close()
         except disconnected_exceptions:
-            pass
\ No newline at end of file
+            pass
