@@ -155,12 +155,13 @@ class PGTextIndex(Persistent):
             text = '%s' % value  # Call the __str__() method
             if text:
                 clauses.append('to_tsvector(%s, %s)')
-                params.extend([self.ts_config, text])
+                params.extend([self.ts_config, _truncate(text)])
             for weight in ('A', 'B', 'C'):
                 text = getattr(value, weight, None)
                 if text:
                     clauses.append('setweight(to_tsvector(%s, %s), %s)')
-                    params.extend([self.ts_config, '%s' % text, weight])
+                    params.extend([self.ts_config, _truncate('%s' % text),
+                                   weight])
 
         else:
             # The value is a simple string.  Strings can not
@@ -168,12 +169,11 @@ class PGTextIndex(Persistent):
             params = [docid, docid, 1.0, None]
             if value:
                 clauses.append('to_tsvector(%s, %s)')
-                params.extend([self.ts_config, '%s' % value])
+                params.extend([self.ts_config, _truncate('%s' % value)])
 
         if len(params) > 4:
             clause = ' || '.join(clauses)
             stmt = """
-            LOCK %(table)s IN EXCLUSIVE MODE;
             DELETE FROM %(table)s WHERE docid = %%s;
             INSERT INTO %(table)s (docid, coefficient, marker, text_vector)
             VALUES (%%s, %%s, %%s, %(clause)s)
@@ -187,7 +187,6 @@ class PGTextIndex(Persistent):
 
     def _index_null(self, docid):
         stmt = """
-        LOCK %(table)s IN EXCLUSIVE MODE;
         DELETE FROM %(table)s WHERE docid = %%s;
         INSERT INTO %(table)s (docid, coefficient, marker, text_vector)
         VALUES (%%s, 0.0, null, null)
@@ -204,20 +203,13 @@ class PGTextIndex(Persistent):
         This call is a no-op if the docid isn't in the index, however,
         after this call, the index should have no references to the docid.
         """
-        stmt = """
-        LOCK %(table)s IN EXCLUSIVE MODE;
-        DELETE FROM %(table)s
-        WHERE docid = %%s
-        """ % self._subs
+        stmt = "DELETE FROM %(table)s WHERE docid = %%s" % self._subs
         self.cursor.execute(stmt, (docid,))
 
     def clear(self):
         """Unindex all documents indexed by the index
         """
-        stmt = """
-        LOCK %(table)s IN EXCLUSIVE MODE;
-        DELETE FROM %(table)s
-        """ % self._subs
+        stmt = "DELETE FROM %(table)s" % self._subs
         self.cursor.execute(stmt)
 
     def _run_query(self, query, invert=False, docids=None):
@@ -293,7 +285,7 @@ class PGTextIndex(Persistent):
         res.update(data)
         return res
 
-    apply = applyEq = applyContains
+    apply = applyEq = applyContains  # @ReservedAssignment
     applyNotEq = applyDoesNotContain
 
     def docids(self):
@@ -458,6 +450,21 @@ def _mp_release_resources(jar):
     jar._release_resources = _release_resources
 
 
+def _truncate(text):
+    """
+    PostgreSQL can't handle ts_vectors that are 1MB or larger.
+    """
+    MAXLEN = 1048575
+    l = len(text)
+    if l <= MAXLEN:
+        return text
+
+    trunc = MAXLEN
+    while text[trunc].isalnum():
+        trunc -= 1
+    return text[:trunc]
+
+
 class SimpleWeightedText(object):
     implements(IWeightedText)
 
