@@ -93,7 +93,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, None)
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -107,7 +106,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, '')
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -121,7 +119,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, [['', ''], ''])
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -135,7 +132,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(5, 'Waldo')
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -143,6 +139,21 @@ class TestPGTextIndex(unittest.TestCase):
         ])
         self.assertEqual(params, (5, 5, 1.0, None, 'english', 'Waldo'))
 
+    def test_index_doc_unweighted_long(self):
+        text = 'Waldo ' * 174763 # Over 1MB
+        index = self._make_one()
+        index.cursor.executed = executed = []
+        index.index_doc(5, text)
+        lines, params = self._format_executed(executed)
+        self.assertEqual(lines, [
+            'DELETE FROM pgtextindex WHERE docid = %s;',
+            'INSERT INTO pgtextindex '
+                '(docid, coefficient, marker, text_vector)',
+            'VALUES (%s, %s, %s, to_tsvector(%s, %s))',
+        ])
+        self.assertEqual(
+            params, (5, 5, 1.0, None, 'english', text[:1048571]))
+
     def test_index_doc_using_attr_discriminator(self):
         class DummyObject:
             name = 'Osvaldo'
@@ -152,7 +163,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, DummyObject())
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -169,7 +179,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, 'dummy')
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -192,7 +201,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(6, DummyObject())
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -206,7 +214,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(5, ['Waldo', 'character'])
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -218,13 +225,31 @@ class TestPGTextIndex(unittest.TestCase):
             'english', 'Waldo', 'A',
         ))
 
+    def test_index_doc_use_one_weight_long(self):
+        text1 = 'Waldo ' * 174763 # Over 1MB
+        text2 = 'Baldo ' * 174763 # Over 1MB
+        index = self._make_one()
+        index.cursor.executed = executed = []
+        index.index_doc(5, [text1, text2])
+        lines, params = self._format_executed(executed)
+        self.assertEqual(lines, [
+            'DELETE FROM pgtextindex WHERE docid = %s;',
+            'INSERT INTO pgtextindex '
+                '(docid, coefficient, marker, text_vector)',
+            'VALUES (%s, %s, %s, to_tsvector(%s, %s) || '
+                'setweight(to_tsvector(%s, %s), %s))',
+        ])
+        self.assertEqual(params, (5, 5, 1.0, None,
+            'english', text2[:1048571],
+            'english', text1[:1048571], 'A',
+        ))
+
     def test_index_doc_use_more_than_all_possible_weights(self):
         index = self._make_one()
         index.cursor.executed = executed = []
         index.index_doc(5, ['Waldo', 'character', 'boy', 'person', 'entity'])
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -246,7 +271,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(5, ['Waldo', '', 'boy', ''])
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -272,7 +296,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(5, DummyText('Where is Waldo'))
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -287,7 +310,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.index_doc(5, [['Waldo', 'Wally'], ''])
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
@@ -303,9 +325,7 @@ class TestPGTextIndex(unittest.TestCase):
         index.unindex_doc(7)
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
-            'DELETE FROM pgtextindex',
-            'WHERE docid = %s',
+            'DELETE FROM pgtextindex WHERE docid = %s',
         ])
         self.assertEqual(params, (7,))
 
@@ -315,7 +335,6 @@ class TestPGTextIndex(unittest.TestCase):
         index.clear()
         lines, params = self._format_executed(executed)
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex',
         ])
         self.assertEqual(params, None)
@@ -694,8 +713,8 @@ class TestPGTextIndex(unittest.TestCase):
         index = self._make_one()
         index.cursor.executed = executed = []
         index.cursor.results = [(5,), (6,)]
-        all = index.family.IF.Set([5, 6, 7])
-        index._migrate_to_0_8_0(all)
+        all_docids = index.family.IF.Set([5, 6, 7])
+        index._migrate_to_0_8_0(all_docids)
         self.assertEqual(len(executed), 2)
         lines, params = self._format_executed([executed[0]])
         self.assertEqual(lines, [
@@ -704,7 +723,6 @@ class TestPGTextIndex(unittest.TestCase):
         self.assertEqual(params, None)
         lines, params = self._format_executed([executed[1]])
         self.assertEqual(lines, [
-            'LOCK pgtextindex IN EXCLUSIVE MODE;',
             'DELETE FROM pgtextindex WHERE docid = %s;',
             'INSERT INTO pgtextindex '
                 '(docid, coefficient, marker, text_vector)',
